@@ -19,16 +19,14 @@ import operator
 from abc import ABC, abstractmethod
 from argparse import Namespace
 from functools import wraps
-from typing import Any, Callable, Dict, Iterable, List, Mapping, MutableMapping, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Sequence, Union
 from weakref import ReferenceType
 
 import numpy as np
-import torch
 
 import pytorch_lightning as pl
 from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
-from pytorch_lightning.utilities import rank_zero_only
-from pytorch_lightning.utilities.warnings import rank_zero_deprecation
+from pytorch_lightning.utilities.rank_zero import rank_zero_deprecation, rank_zero_only
 
 
 def rank_zero_experiment(fn: Callable) -> Callable:
@@ -57,6 +55,10 @@ class LightningLoggerBase(ABC):
             is not presented in the `agg_key_funcs` dictionary, then the
             `agg_default_func` will be used for aggregation.
 
+        .. deprecated:: v1.6
+            The parameters `agg_key_funcs` and `agg_default_func` are deprecated
+            in v1.6 and will be removed in v1.8.
+
     Note:
         The `agg_key_funcs` and `agg_default_func` arguments are used only when
         one logs metrics with the :meth:`~LightningLoggerBase.agg_and_log_metrics` method.
@@ -65,12 +67,26 @@ class LightningLoggerBase(ABC):
     def __init__(
         self,
         agg_key_funcs: Optional[Mapping[str, Callable[[Sequence[float]], float]]] = None,
-        agg_default_func: Callable[[Sequence[float]], float] = np.mean,
+        agg_default_func: Optional[Callable[[Sequence[float]], float]] = None,
     ):
         self._prev_step: int = -1
         self._metrics_to_agg: List[Dict[str, float]] = []
-        self._agg_key_funcs = agg_key_funcs if agg_key_funcs else {}
-        self._agg_default_func = agg_default_func
+        if agg_key_funcs:
+            self._agg_key_funcs = agg_key_funcs
+            rank_zero_deprecation(
+                "The `agg_key_funcs` parameter for `LightningLoggerBase` was deprecated in v1.6"
+                " and will be removed in v1.8."
+            )
+        else:
+            self._agg_key_funcs = {}
+        if agg_default_func:
+            self._agg_default_func = agg_default_func
+            rank_zero_deprecation(
+                "The `agg_default_func` parameter for `LightningLoggerBase` was deprecated in v1.6"
+                " and will be removed in v1.8."
+            )
+        else:
+            self._agg_default_func = np.mean
 
     def after_save_checkpoint(self, checkpoint_callback: "ReferenceType[ModelCheckpoint]") -> None:
         """Called after model checkpoint callback saves a new checkpoint.
@@ -87,6 +103,9 @@ class LightningLoggerBase(ABC):
     ):
         """Update aggregation methods.
 
+        .. deprecated:: v1.6
+            `update_agg_funcs` is deprecated in v1.6 and will be removed in v1.8.
+
         Args:
             agg_key_funcs:
                 Dictionary which maps a metric name to a function, which will
@@ -100,69 +119,23 @@ class LightningLoggerBase(ABC):
             self._agg_key_funcs.update(agg_key_funcs)
         if agg_default_func:
             self._agg_default_func = agg_default_func
-
-    @property
-    @abstractmethod
-    def experiment(self) -> Any:
-        """Return the experiment object associated with this logger."""
-
-    def _aggregate_metrics(
-        self, metrics: Dict[str, float], step: Optional[int] = None
-    ) -> Tuple[int, Optional[Dict[str, float]]]:
-        """Aggregates metrics.
-
-        Args:
-            metrics: Dictionary with metric names as keys and measured quantities as values
-            step: Step number at which the metrics should be recorded
-
-        Returns:
-            Step and aggregated metrics. The return value could be ``None``. In such case, metrics
-            are added to the aggregation list, but not aggregated yet.
-        """
-        # if you still receiving metric from the same step, just accumulate it
-        if step == self._prev_step:
-            self._metrics_to_agg.append(metrics)
-            return step, None
-
-        # compute the metrics
-        agg_step, agg_mets = self._reduce_agg_metrics()
-
-        # as new step received reset accumulator
-        self._metrics_to_agg = [metrics]
-        self._prev_step = step
-        return agg_step, agg_mets
-
-    def _reduce_agg_metrics(self):
-        """Aggregate accumulated metrics."""
-        # compute the metrics
-        if not self._metrics_to_agg:
-            agg_mets = None
-        elif len(self._metrics_to_agg) == 1:
-            agg_mets = self._metrics_to_agg[0]
-        else:
-            agg_mets = merge_dicts(self._metrics_to_agg, self._agg_key_funcs, self._agg_default_func)
-        return self._prev_step, agg_mets
-
-    def _finalize_agg_metrics(self):
-        """This shall be called before save/close."""
-        agg_step, metrics_to_log = self._reduce_agg_metrics()
-        self._metrics_to_agg = []
-
-        if metrics_to_log is not None:
-            self.log_metrics(metrics=metrics_to_log, step=agg_step)
+        rank_zero_deprecation(
+            "`LightningLoggerBase.update_agg_funcs` was deprecated in v1.6 and will be removed in v1.8."
+        )
 
     def agg_and_log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None):
         """Aggregates and records metrics. This method doesn't log the passed metrics instantaneously, but instead
         it aggregates them and logs only if metrics are ready to be logged.
 
+        .. deprecated:: v1.6
+            This method is deprecated in v1.6 and will be removed in v1.8.
+            Please use `LightningLoggerBase.log_metrics` instead.
+
         Args:
             metrics: Dictionary with metric names as keys and measured quantities as values
             step: Step number at which the metrics should be recorded
         """
-        agg_step, metrics_to_log = self._aggregate_metrics(metrics=metrics, step=step)
-
-        if metrics_to_log:
-            self.log_metrics(metrics=metrics_to_log, step=agg_step)
+        self.log_metrics(metrics=metrics, step=step)
 
     @abstractmethod
     def log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None):
@@ -178,107 +151,6 @@ class LightningLoggerBase(ABC):
         """
         pass
 
-    @staticmethod
-    def _convert_params(params: Union[Dict[str, Any], Namespace]) -> Dict[str, Any]:
-        # in case converting from namespace
-        if isinstance(params, Namespace):
-            params = vars(params)
-
-        if params is None:
-            params = {}
-
-        return params
-
-    @staticmethod
-    def _sanitize_callable_params(params: Dict[str, Any]) -> Dict[str, Any]:
-        """Sanitize callable params dict, e.g. ``{'a': <function_**** at 0x****>} -> {'a': 'function_****'}``.
-
-        Args:
-            params: Dictionary containing the hyperparameters
-
-        Returns:
-            dictionary with all callables sanitized
-        """
-
-        def _sanitize_callable(val):
-            # Give them one chance to return a value. Don't go rabbit hole of recursive call
-            if isinstance(val, Callable):
-                try:
-                    _val = val()
-                    if isinstance(_val, Callable):
-                        return val.__name__
-                    return _val
-                # todo: specify the possible exception
-                except Exception:
-                    return getattr(val, "__name__", None)
-            return val
-
-        return {key: _sanitize_callable(val) for key, val in params.items()}
-
-    @staticmethod
-    def _flatten_dict(params: Dict[Any, Any], delimiter: str = "/") -> Dict[str, Any]:
-        """Flatten hierarchical dict, e.g. ``{'a': {'b': 'c'}} -> {'a/b': 'c'}``.
-
-        Args:
-            params: Dictionary containing the hyperparameters
-            delimiter: Delimiter to express the hierarchy. Defaults to ``'/'``.
-
-        Returns:
-            Flattened dict.
-
-        Examples:
-            >>> LightningLoggerBase._flatten_dict({'a': {'b': 'c'}})
-            {'a/b': 'c'}
-            >>> LightningLoggerBase._flatten_dict({'a': {'b': 123}})
-            {'a/b': 123}
-            >>> LightningLoggerBase._flatten_dict({5: {'a': 123}})
-            {'5/a': 123}
-        """
-
-        def _dict_generator(input_dict, prefixes=None):
-            prefixes = prefixes[:] if prefixes else []
-            if isinstance(input_dict, MutableMapping):
-                for key, value in input_dict.items():
-                    key = str(key)
-                    if isinstance(value, (MutableMapping, Namespace)):
-                        value = vars(value) if isinstance(value, Namespace) else value
-                        yield from _dict_generator(value, prefixes + [key])
-                    else:
-                        yield prefixes + [key, value if value is not None else str(None)]
-            else:
-                yield prefixes + [input_dict if input_dict is None else str(input_dict)]
-
-        return {delimiter.join(keys): val for *keys, val in _dict_generator(params)}
-
-    @staticmethod
-    def _sanitize_params(params: Dict[str, Any]) -> Dict[str, Any]:
-        """Returns params with non-primitvies converted to strings for logging.
-
-        >>> params = {"float": 0.3,
-        ...           "int": 1,
-        ...           "string": "abc",
-        ...           "bool": True,
-        ...           "list": [1, 2, 3],
-        ...           "namespace": Namespace(foo=3),
-        ...           "layer": torch.nn.BatchNorm1d}
-        >>> import pprint
-        >>> pprint.pprint(LightningLoggerBase._sanitize_params(params))  # doctest: +NORMALIZE_WHITESPACE
-        {'bool': True,
-         'float': 0.3,
-         'int': 1,
-         'layer': "<class 'torch.nn.modules.batchnorm.BatchNorm1d'>",
-         'list': '[1, 2, 3]',
-         'namespace': 'Namespace(foo=3)',
-         'string': 'abc'}
-        """
-        for k in params.keys():
-            # convert relevant np scalars to python types first (instead of str)
-            if isinstance(params[k], (np.bool_, np.integer, np.floating)):
-                params[k] = params[k].item()
-            elif type(params[k]) not in [bool, int, float, str, torch.Tensor]:
-                params[k] = str(params[k])
-        return params
-
     @abstractmethod
     def log_hyperparams(self, params: argparse.Namespace, *args, **kwargs):
         """Record hyperparameters.
@@ -286,7 +158,7 @@ class LightningLoggerBase(ABC):
         Args:
             params: :class:`~argparse.Namespace` containing the hyperparameters
             args: Optional positional arguments, depends on the specific logger being used
-            kwargs: Optional keywoard arguments, depends on the specific logger being used
+            kwargs: Optional keyword arguments, depends on the specific logger being used
         """
 
     def log_graph(self, model: "pl.LightningModule", input_array=None) -> None:
@@ -298,23 +170,8 @@ class LightningLoggerBase(ABC):
         """
         pass
 
-    def log_text(self, *args, **kwargs) -> None:
-        """Log text.
-
-        Arguments are directly passed to the logger.
-        """
-        raise NotImplementedError
-
-    def log_image(self, *args, **kwargs) -> None:
-        """Log image.
-
-        Arguments are directly passed to the logger.
-        """
-        raise NotImplementedError
-
     def save(self) -> None:
         """Save log data."""
-        self._finalize_agg_metrics()
 
     def finalize(self, status: str) -> None:
         """Do any processing that is necessary to finalize an experiment.
@@ -360,16 +217,14 @@ class LightningLoggerBase(ABC):
     def version(self) -> Union[int, str]:
         """Return the experiment version."""
 
-    def _add_prefix(self, metrics: Dict[str, float]):
-        if self._prefix:
-            metrics = {f"{self._prefix}{self.LOGGER_JOIN_CHAR}{k}": v for k, v in metrics.items()}
-
-        return metrics
-
 
 class LoggerCollection(LightningLoggerBase):
     """The :class:`LoggerCollection` class is used to iterate all logging actions over the given `logger_iterable`.
 
+    .. deprecated:: v1.6
+        `LoggerCollection` is deprecated in v1.6 and will be removed in v1.8.
+        Directly pass a list of loggers to the Trainer and access the list via the `trainer.loggers` attribute.
+
     Args:
         logger_iterable: An iterable collection of loggers
     """
@@ -377,6 +232,10 @@ class LoggerCollection(LightningLoggerBase):
     def __init__(self, logger_iterable: Iterable[LightningLoggerBase]):
         super().__init__()
         self._logger_iterable = logger_iterable
+        rank_zero_deprecation(
+            "`LoggerCollection` is deprecated in v1.6 and will be removed in v1.8. Directly pass a list of loggers"
+            " to the Trainer and access the list via the `trainer.loggers` attribute."
+        )
 
     def __getitem__(self, index: int) -> LightningLoggerBase:
         return list(self._logger_iterable)[index]
@@ -400,11 +259,11 @@ class LoggerCollection(LightningLoggerBase):
 
     def agg_and_log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None):
         for logger in self._logger_iterable:
-            logger.agg_and_log_metrics(metrics, step)
+            logger.agg_and_log_metrics(metrics=metrics, step=step)
 
     def log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None) -> None:
         for logger in self._logger_iterable:
-            logger.log_metrics(metrics, step)
+            logger.log_metrics(metrics=metrics, step=step)
 
     def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:
         for logger in self._logger_iterable:
@@ -452,13 +311,15 @@ class LoggerCollection(LightningLoggerBase):
 
     @property
     def name(self) -> str:
-        """Returns the experiment names for all the loggers in the logger collection joined by an underscore."""
-        return "_".join(str(logger.name) for logger in self._logger_iterable)
+        """Returns the unique experiment names for all the loggers in the logger collection joined by an
+        underscore."""
+        return "_".join(dict.fromkeys(str(logger.name) for logger in self._logger_iterable))
 
     @property
     def version(self) -> str:
-        """Returns the experiment versions for all the loggers in the logger collection joined by an underscore."""
-        return "_".join(str(logger.version) for logger in self._logger_iterable)
+        """Returns the unique experiment versions for all the loggers in the logger collection joined by an
+        underscore."""
+        return "_".join(dict.fromkeys(str(logger.version) for logger in self._logger_iterable))
 
 
 class DummyExperiment:
