@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional, Tuple, Union
 
 from deprecate import void
 from torch import Tensor
@@ -32,23 +32,23 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
 
     def __init__(self) -> None:
         super().__init__()
-        self.accumulated_loss: Optional[Tensor] = None
-        self.running_loss: TensorRunningAccum = TensorRunningAccum(window_length=20)
+        self.accumulated_loss = TensorRunningAccum(window_length=20)
+        self.running_loss = TensorRunningAccum(window_length=20)
         # the current split index when the batch gets split into chunks in truncated backprop through time
-        self.split_idx: Optional[int] = None
+        self.split_idx: int = 0
         self.optimizer_loop = OptimizerLoop()
         self.manual_loop = ManualOptimization()
 
         self._outputs: _OUTPUTS_TYPE = []
-        self._remaining_splits: Optional[List[Any]] = None
+        self._remaining_splits: List[Tuple[int, Any]] = []
 
     @property
     def done(self) -> bool:
         """Returns if all batch splits have been processed already."""
         return len(self._remaining_splits) == 0
 
-    def connect(
-        self, optimizer_loop: Optional["Loop"] = None, manual_loop: Optional[ManualOptimization] = None
+    def connect(  # type: ignore[override]
+        self, optimizer_loop: Optional[OptimizerLoop] = None, manual_loop: Optional[ManualOptimization] = None
     ) -> None:
         if optimizer_loop is not None:
             self.optimizer_loop = optimizer_loop
@@ -59,7 +59,7 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
         """Resets the loop state."""
         self._outputs = []
 
-    def on_run_start(self, batch: Any, batch_idx: int):
+    def on_run_start(self, batch: Any, batch_idx: int) -> None:  # type: ignore[override]
         """Splits the data into tbptt splits.
 
         Args:
@@ -69,7 +69,7 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
         void(batch_idx)
         self._remaining_splits = list(enumerate(self._tbptt_split_batch(batch)))
 
-    def advance(self, batch, batch_idx):
+    def advance(self, batch: Any, batch_idx: int) -> None:  # type: ignore[override]
         """Runs the train step together with optimization (if necessary) on the current batch split.
 
         Args:
@@ -79,9 +79,9 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
         void(batch)
         self.split_idx, split_batch = self._remaining_splits.pop(0)
 
-        # let logger connector extract current batch size
-        self.trainer.logger_connector.on_train_split_start(self.split_idx, split_batch)
+        self.trainer._logger_connector.on_train_split_start(self.split_idx)
 
+        outputs: Optional[Union[_OPTIMIZER_LOOP_OUTPUTS_TYPE, _MANUAL_LOOP_OUTPUTS_TYPE]] = None  # for mypy
         # choose which loop will run the optimization
         if self.trainer.lightning_module.automatic_optimization:
             optimizers = _get_active_optimizers(self.trainer.optimizers, self.trainer.optimizer_frequencies, batch_idx)
@@ -98,12 +98,18 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
         self.optimizer_loop._hiddens = None
         # this is not necessary as the manual loop runs for only 1 iteration, but just in case
         self.manual_loop._hiddens = None
-        output, self._outputs = self._outputs, None  # free memory
+        output, self._outputs = self._outputs, []  # free memory
+        self._remaining_splits = []
         return output
 
     def teardown(self) -> None:
+        self.optimizer_loop.teardown()
+        self.manual_loop.teardown()
         # release memory
-        self._remaining_splits = None
+        if self.accumulated_loss.memory is not None:
+            self.accumulated_loss.memory = self.accumulated_loss.memory.cpu()
+        if self.running_loss.memory is not None:
+            self.running_loss.memory = self.running_loss.memory.cpu()
 
     def _tbptt_split_batch(self, batch: Any) -> List[Any]:
         """Splits a single batch into a list of sequence steps for tbptt.
@@ -115,9 +121,7 @@ class TrainingBatchLoop(Loop[_OUTPUTS_TYPE]):
         if tbptt_steps == 0:
             return [batch]
 
-        model_ref = self.trainer.lightning_module
-        with self.trainer.profiler.profile("tbptt_split_batch"):
-            splits = model_ref.tbptt_split_batch(batch, tbptt_steps)
+        splits = self.trainer._call_lightning_module_hook("tbptt_split_batch", batch, tbptt_steps)
         return splits
 
     def _update_running_loss(self, current_loss: Tensor) -> None:
