@@ -195,7 +195,7 @@ class EvaluationEpochLoop(Loop):
         if isinstance(dataloader, CombinedLoader):
             raise MisconfigurationException(
                 "Reloading support hasn't been implemented for `CombinedLoader`. You can request it by opening an issue"
-                " in `https://github.com/PyTorchLightning/pytorch-lightning/issues`."
+                " in `https://github.com/Lightning-AI/lightning/issues`."
             )
         assert isinstance(dataloader, DataLoader)
         _reload_dataloader_state_dict(dataloader, self._dataloader_state_dict)
