@@ -13,7 +13,7 @@
 # limitations under the License.
 import contextlib
 from functools import partial
-from typing import Any, Callable, Generator, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Union
 
 import torch
 from torch import Tensor
@@ -22,7 +22,7 @@ from torch.optim import Optimizer
 
 import pytorch_lightning as pl
 from pytorch_lightning.core.hooks import CheckpointHooks
-from pytorch_lightning.utilities import grad_norm, GradClipAlgorithmType, rank_zero_deprecation
+from pytorch_lightning.utilities import grad_norm, GradClipAlgorithmType
 from pytorch_lightning.utilities.types import _PARAMETERS
 
 
@@ -34,19 +34,6 @@ class PrecisionPlugin(CheckpointHooks):
 
     precision: Union[str, int] = 32
 
-    def master_params(self, optimizer: Optimizer) -> _PARAMETERS:
-        """The main params of the model.
-
-        .. deprecated:: v1.5
-
-            This method is deprecated in v1.5 and will be removed in v1.6. Use :meth:`main_params` instead.
-        """
-        rank_zero_deprecation(
-            f"`{self.__class__.__name__}.master_params` was deprecated in v1.5 and will be removed in v1.6."
-            f" Use `main_params` instead."
-        )
-        return self.main_params(optimizer)
-
     def main_params(self, optimizer: Optimizer) -> _PARAMETERS:
         """The main params of the model.
 
@@ -68,7 +55,9 @@ class PrecisionPlugin(CheckpointHooks):
             model: the model to be optimized
             closure_loss: the loss value obtained from the closure
         """
-        model.trainer.call_hook("on_before_backward", closure_loss)
+        assert model.trainer is not None
+        model.trainer._call_callback_hooks("on_before_backward", closure_loss)
+        model.trainer._call_lightning_module_hook("on_before_backward", closure_loss)
         return closure_loss
 
     def backward(
@@ -101,7 +90,9 @@ class PrecisionPlugin(CheckpointHooks):
         """
         # once backward has been applied, release graph
         closure_loss = closure_loss.detach()
-        model.trainer.call_hook("on_after_backward")
+        assert model.trainer is not None
+        model.trainer._call_callback_hooks("on_after_backward")
+        model.trainer._call_lightning_module_hook("on_after_backward")
         return closure_loss
 
     def _run_backward(self, tensor: Tensor, model: Optional[Module], *args: Any, **kwargs: Any) -> None:
@@ -120,7 +111,8 @@ class PrecisionPlugin(CheckpointHooks):
             return
         trainer = model.trainer
         assert trainer is not None
-        trainer.call_hook("on_before_optimizer_step", optimizer, optimizer_idx)
+        trainer._call_callback_hooks("on_before_optimizer_step", optimizer, optimizer_idx)
+        trainer._call_lightning_module_hook("on_before_optimizer_step", optimizer, optimizer_idx)
         # TODO: this is done for the entire model but should be changed to per-optimizer
         if optimizer_idx == 0:
             self._track_grad_norm(trainer)
@@ -156,16 +148,20 @@ class PrecisionPlugin(CheckpointHooks):
         optimizer_idx: int,
         closure: Callable[[], Any],
         **kwargs: Any,
-    ) -> None:
+    ) -> Any:
         """Hook to run the optimizer step."""
         if isinstance(model, pl.LightningModule):
             closure = partial(self._wrap_closure, model, optimizer, optimizer_idx, closure)
-        optimizer.step(closure=closure, **kwargs)
+        return optimizer.step(closure=closure, **kwargs)
 
     def _track_grad_norm(self, trainer: "pl.Trainer") -> None:
         if trainer.track_grad_norm == -1:
             return
-        kwargs = {"group_separator": trainer.logger.group_separator} if trainer.logger is not None else {}
+
+        kwargs = {}
+        if len(trainer.loggers) == 1:
+            kwargs["group_separator"] = trainer.loggers[0].group_separator
+
         grad_norm_dict = grad_norm(trainer.lightning_module, trainer.track_grad_norm, **kwargs)
         if grad_norm_dict:
             prev_fx = trainer.lightning_module._current_fx_name
@@ -215,14 +211,8 @@ class PrecisionPlugin(CheckpointHooks):
         parameters = self.main_params(optimizer)
         torch.nn.utils.clip_grad_norm_(parameters, clip_val)
 
-    def pre_dispatch(self) -> None:
-        """Hook to do something before the training/evaluation/prediction starts."""
-
     def dispatch(self, trainer: "pl.Trainer") -> None:
-        """Hook to do something when ``Accelerator.dispatch()`` gets called."""
-
-    def post_dispatch(self) -> None:
-        """Hook to do something after the training/evaluation/prediction finishes."""
+        """Hook to do something when ``Strategy.dispatch()`` gets called."""
 
     @contextlib.contextmanager
     def forward_context(self) -> Generator[None, None, None]:
@@ -252,3 +242,38 @@ class PrecisionPlugin(CheckpointHooks):
         """A contextmanager for the predict step."""
         with self.forward_context():
             yield
+
+    def teardown(self) -> None:
+        """This method is called to teardown the training process.
+
+        It is the right place to release memory and free other resources.
+        """
+
+    def state_dict(self) -> Dict[str, Any]:
+        """Called when saving a checkpoint, implement to generate precision plugin state_dict.
+
+        Returns:
+            A dictionary containing precision plugin state.
+        """
+        return {}
+
+    def load_state_dict(self, state_dict: Dict[str, Any]) -> None:
+        """Called when loading a checkpoint, implement to reload precision plugin state given precision plugin
+        state_dict.
+
+        Args:
+            state_dict: the precision plugin state returned by ``state_dict``.
+        """
+        pass
+
+    def on_save_checkpoint(self, checkpoint: Dict[str, Any]) -> None:
+        """``PrecisionPlugin.on_save_checkpoint`` was deprecated in v1.6 and will be removed in v1.8.
+
+        Use ``state_dict`` instead.
+        """
+
+    def on_load_checkpoint(self, checkpoint: Dict[str, Any]) -> None:
+        """``PrecisionPlugin.on_load_checkpoint`` was deprecated in v1.6 and will be removed in v1.8.
+
+        Use ``load_state_dict`` instead.
+        """
