@@ -31,15 +31,25 @@ class _FxValidator:
         "on_before_backward": _LogOptions(
             allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
         ),
+        "backward": _LogOptions(
+            allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
+        ),
         "on_after_backward": _LogOptions(
             allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
         ),
         "on_before_optimizer_step": _LogOptions(
             allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
         ),
+        "optimizer_step": _LogOptions(
+            allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
+        ),
+        "lr_scheduler_step": None,
         "on_before_zero_grad": _LogOptions(
             allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
         ),
+        "optimizer_zero_grad": _LogOptions(
+            allowed_on_step=(False, True), allowed_on_epoch=(False, True), default_on_step=True, default_on_epoch=False
+        ),
         "on_init_start": None,
         "on_init_end": None,
         "on_fit_start": None,
@@ -116,8 +126,10 @@ class _FxValidator:
         "on_predict_batch_end": None,
         "on_keyboard_interrupt": None,
         "on_exception": None,
+        "state_dict": None,
         "on_save_checkpoint": None,
         "on_load_checkpoint": None,
+        "load_state_dict": None,
         "setup": None,
         "teardown": None,
         "configure_sharded_model": None,
@@ -160,6 +172,8 @@ class _FxValidator:
         "configure_callbacks": None,
         "on_validation_model_eval": None,
         "on_test_model_eval": None,
+        "on_validation_model_train": None,
+        "on_test_model_train": None,
     }
 
     @classmethod
@@ -168,7 +182,7 @@ class _FxValidator:
         if fx_name not in cls.functions:
             raise RuntimeError(
                 f"Logging inside `{fx_name}` is not implemented."
-                " Please, open an issue in `https://github.com/PyTorchLightning/pytorch-lightning/issues`."
+                " Please, open an issue in `https://github.com/Lightning-AI/lightning/issues`."
             )
 
         if cls.functions[fx_name] is None:
