@@ -8,7 +8,9 @@ from types import FrameType
 from typing import Any, Callable, Dict, List, Set, Union
 
 import pytorch_lightning as pl
+from pytorch_lightning.plugins.environments import SLURMEnvironment
 from pytorch_lightning.utilities.imports import _fault_tolerant_training, _IS_WINDOWS
+from pytorch_lightning.utilities.rank_zero import rank_zero_info
 
 # copied from signal.pyi
 _SIGNUM = Union[int, signal.Signals]
@@ -44,15 +46,16 @@ class SignalConnector:
         sigterm_handlers: List[_HANDLER] = []
 
         if _fault_tolerant_training():
-            sigusr1_handlers.append(self.fault_tolerant_sigusr1_handler_fn)
+            sigterm_handlers.append(self.fault_tolerant_sigterm_handler_fn)
 
-        if self._is_on_slurm():
-            log.info("Set SLURM handle signals.")
+        environment = self.trainer._accelerator_connector.cluster_environment
+        if isinstance(environment, SLURMEnvironment) and environment.auto_requeue:
+            log.info("SLURM auto-requeueing enabled. Setting signal handlers.")
             sigusr1_handlers.append(self.slurm_sigusr1_handler_fn)
             sigterm_handlers.append(self.sigterm_handler_fn)
 
         # signal.SIGUSR1 doesn't seem available on windows
-        if not _IS_WINDOWS:
+        if not self._is_on_windows():
             if sigusr1_handlers and not self._has_already_handler(signal.SIGUSR1):
                 self._register_signal(signal.SIGUSR1, HandlersCompose(sigusr1_handlers))
 
@@ -60,11 +63,16 @@ class SignalConnector:
                 self._register_signal(signal.SIGTERM, HandlersCompose(sigterm_handlers))
 
     def slurm_sigusr1_handler_fn(self, signum: _SIGNUM, frame: FrameType) -> None:
-        if self.trainer.is_global_zero:
-            # save weights
-            log.info("handling SIGUSR1")
-            self.trainer.checkpoint_connector.hpc_save(self.trainer.weights_save_path, self.trainer.logger)
+        rank_zero_info("handling SIGUSR1")
 
+        # save logger to make sure we get all the metrics
+        for logger in self.trainer.loggers:
+            logger.finalize("finished")
+        # TODO: in v1.8 change this to use self.trainer.default_root_dir
+        hpc_save_path = self.trainer._checkpoint_connector.hpc_save_path(self.trainer._weights_save_path_internal)
+        self.trainer.save_checkpoint(hpc_save_path)
+
+        if self.trainer.is_global_zero:
             # find job id
             job_id = os.environ["SLURM_JOB_ID"]
             cmd = ["scontrol", "requeue", job_id]
@@ -86,18 +94,15 @@ class SignalConnector:
             else:
                 log.warning("requeue failed...")
 
-            # close experiment to avoid issues
-            if self.trainer.logger:
-                self.trainer.logger.finalize("finished")
-
-    def fault_tolerant_sigusr1_handler_fn(self, signum: _SIGNUM, frame: FrameType) -> None:
+    def fault_tolerant_sigterm_handler_fn(self, signum: _SIGNUM, frame: FrameType) -> None:
+        log.info(f"Received signal {signum}. Saving a fault-tolerant checkpoint and terminating.")
         self.trainer._terminate_gracefully = True
 
     def sigterm_handler_fn(self, signum: _SIGNUM, frame: FrameType) -> None:
         log.info("bypassing sigterm")
 
     def teardown(self) -> None:
-        """Restores the signals that were previsouly configured before :class:`SignalConnector` replaced them."""
+        """Restores the signals that were previously configured before :class:`SignalConnector` replaced them."""
         for signum, handler in self._original_handlers.items():
             if handler is not None:
                 self._register_signal(signum, handler)
@@ -130,21 +135,13 @@ class SignalConnector:
                 signal.SIGINT,
                 signal.SIGSEGV,
                 signal.SIGTERM,
+                signal.SIGBREAK,
             }
         return set(signal.Signals)
 
-    def _is_on_slurm(self) -> bool:
-        # see if we're using slurm (not interactive)
-        on_slurm = False
-        try:
-            job_name = os.environ["SLURM_JOB_NAME"]
-            if job_name != "bash":
-                on_slurm = True
-        # todo: specify the possible exception
-        except Exception:
-            pass
-
-        return on_slurm
+    @staticmethod
+    def _is_on_windows() -> bool:
+        return sys.platform == "win32"
 
     @staticmethod
     def _has_already_handler(signum: _SIGNUM) -> bool:
