@@ -11,16 +11,22 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+"""Utilities for Argument Parsing within Lightning Components."""
+
 import inspect
 import os
 from abc import ABC
 from argparse import _ArgumentGroup, ArgumentParser, Namespace
+from ast import literal_eval
 from contextlib import suppress
-from typing import Any, Callable, Dict, List, Tuple, Type, Union
+from functools import wraps
+from typing import Any, Callable, cast, Dict, List, Tuple, Type, TypeVar, Union
 
 import pytorch_lightning as pl
 from pytorch_lightning.utilities.parsing import str_to_bool, str_to_bool_or_int, str_to_bool_or_str
 
+_T = TypeVar("_T", bound=Callable[..., Any])
+
 
 class ParseArgparserDataType(ABC):
     def __init__(self, *_: Any, **__: Any) -> None:
@@ -34,8 +40,8 @@ class ParseArgparserDataType(ABC):
 def from_argparse_args(
     cls: Type[ParseArgparserDataType], args: Union[Namespace, ArgumentParser], **kwargs: Any
 ) -> ParseArgparserDataType:
-    """Create an instance from CLI arguments. Eventually use varibles from OS environement which are defined as
-    "PL_<CLASS-NAME>_<CLASS_ARUMENT_NAME>".
+    """Create an instance from CLI arguments. Eventually use variables from OS environment which are defined as
+    ``"PL_<CLASS-NAME>_<CLASS_ARUMENT_NAME>"``.
 
     Args:
         cls: Lightning class
@@ -44,7 +50,8 @@ def from_argparse_args(
         **kwargs: Additional keyword arguments that may override ones in the parser or namespace.
             These must be valid Trainer arguments.
 
-    Example:
+    Examples:
+
         >>> from pytorch_lightning import Trainer
         >>> parser = ArgumentParser(add_help=False)
         >>> parser = Trainer.add_argparse_args(parser)
@@ -93,7 +100,8 @@ def parse_argparser(cls: Type["pl.Trainer"], arg_parser: Union[ArgumentParser, N
 def parse_env_variables(cls: Type["pl.Trainer"], template: str = "PL_%(cls_name)s_%(cls_argument)s") -> Namespace:
     """Parse environment arguments if they are defined.
 
-    Example:
+    Examples:
+
         >>> from pytorch_lightning import Trainer
         >>> parse_env_variables(Trainer)
         Namespace()
@@ -114,7 +122,7 @@ def parse_env_variables(cls: Type["pl.Trainer"], template: str = "PL_%(cls_name)
             # todo: specify the possible exception
             with suppress(Exception):
                 # converting to native types like int/float/bool
-                val = eval(val)
+                val = literal_eval(val)
             env_args[arg_name] = val
     return Namespace(**env_args)
 
@@ -184,14 +192,14 @@ def add_argparse_args(
 
     Examples:
 
-        # Option 1: Default usage.
+        >>> # Option 1: Default usage.
         >>> import argparse
         >>> from pytorch_lightning import Trainer
         >>> parser = argparse.ArgumentParser()
         >>> parser = Trainer.add_argparse_args(parser)
         >>> args = parser.parse_args([])
 
-        # Option 2: Disable use_argument_group (old behavior).
+        >>> # Option 2: Disable use_argument_group (old behavior).
         >>> import argparse
         >>> from pytorch_lightning import Trainer
         >>> parser = argparse.ArgumentParser()
@@ -312,3 +320,22 @@ def _precision_allowed_type(x: Union[int, str]) -> Union[int, str]:
         return int(x)
     except ValueError:
         return x
+
+
+def _defaults_from_env_vars(fn: _T) -> _T:
+    @wraps(fn)
+    def insert_env_defaults(self: Any, *args: Any, **kwargs: Any) -> Any:
+        cls = self.__class__  # get the class
+        if args:  # in case any args passed move them to kwargs
+            # parse only the argument names
+            cls_arg_names = [arg[0] for arg in get_init_arguments_and_types(cls)]
+            # convert args to kwargs
+            kwargs.update(dict(zip(cls_arg_names, args)))
+        env_variables = vars(parse_env_variables(cls))
+        # update the kwargs by env variables
+        kwargs = dict(list(env_variables.items()) + list(kwargs.items()))
+
+        # all args were already moved to kwargs
+        return fn(self, **kwargs)
+
+    return cast(_T, insert_env_defaults)
