@@ -11,8 +11,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Helper functions to operate on metric values. """
-import numbers
+"""Helper functions to operate on metric values."""
+from __future__ import annotations
+
 from typing import Any
 
 import torch
@@ -22,15 +23,14 @@ from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
 
 def metrics_to_scalars(metrics: Any) -> Any:
-    """
-    Recursively walk through a collection and convert single-item tensors to scalar values
+    """Recursively walk through a collection and convert single-item tensors to scalar values.
 
     Raises:
         MisconfigurationException:
             If tensors inside ``metrics`` contains multiple elements, hence preventing conversion to a scalar.
     """
 
-    def to_item(value: torch.Tensor) -> numbers.Number:
+    def to_item(value: torch.Tensor) -> int | float | bool:
         if value.numel() != 1:
             raise MisconfigurationException(
                 f"The metric `{value}` does not contain a single element, thus it cannot be converted to a scalar."
